@@ -2,7 +2,8 @@ use 5.006;
 use strict;
 use warnings;
 package CPAN::Reporter::Smoker;
-our $VERSION = '0.25'; # VERSION
+
+our $VERSION = '0.27';
 
 use Carp;
 use Config;
@@ -15,6 +16,7 @@ use Fcntl ':flock';
 use File::Basename qw/basename dirname/;
 use File::Spec 3.27;
 use File::Temp 0.20;
+use List::Util 1.03 qw/shuffle/;
 use Probe::Perl 0.01;
 use Term::Title 0.01;
 
@@ -63,6 +65,10 @@ my %spec = (
     default => 0,
     is_valid => sub { /^[01]$/ },
   },
+  'random' => {
+    default => 0,
+    is_valid => sub { /^[01]$/ },
+  },
   force_trust => {
     default => 0,
     is_valid => sub { /^[01]$/ },
@@ -75,6 +81,10 @@ my %spec = (
     default => undef,
     is_valid => sub { !defined $_ || ref $_ eq 'SUB' }
   },
+  skip_dev_versions => {
+    default => 0,
+    is_valid => sub { /^[01]$/ },
+  },
 );
 
 sub start {
@@ -149,7 +159,7 @@ sub start {
       CPAN::Index->reload;
       $CPAN::Frontend->mywarn( "Smoker: scanning and sorting index\n");
 
-      $dists = _parse_module_index( $package, $find_ls );
+      $dists = _parse_module_index( $package, $find_ls, $args{skip_dev_versions} );
 
       $CPAN::Frontend->mywarn( "Smoker: found " . scalar @$dists . " distributions on CPAN\n");
     }
@@ -159,6 +169,11 @@ sub start {
       $dists = [ reverse @$dists ];
     }
 
+    # Maybe shuffle the list
+    if ( $args{'random'} ) {
+      $dists = [ shuffle @$dists ];
+    }
+
     # Check if we need to manually reset test history during each dist loop
     my $reset_string = q{};
     if ( $CPAN::Config->{build_dir_reuse}
@@ -381,7 +396,7 @@ sub _base_name {
 #--------------------------------------------------------------------------#-
 
 sub _parse_module_index {
-    my ( $packages, $file_ls ) = @_;
+    my ( $packages, $file_ls, $skip_dev_versions ) = @_;
 
     # first walk the packages list
     # and build an index
@@ -470,6 +485,8 @@ sub _parse_module_index {
             # skip unless there's a matching base from the packages file
             next unless $latest{$base_name};
 
+            next if $skip_dev_versions;
+
             # keep only the latest
             $latest_dev{$base_name} ||= { datetime => 0 };
             if ( $stat{datetime} > $latest_dev{$base_name}{datetime} ) {
@@ -517,7 +534,7 @@ CPAN::Reporter::Smoker - Turnkey CPAN Testers smoking
 
 =head1 VERSION
 
-version 0.25
+version 0.27
 
 =head1 SYNOPSIS
 
@@ -617,6 +634,11 @@ integer; Defaults to 43200 seconds (12 hours)
 
 =item *
 
+C<<< skip_dev_versions >>> -- if true, unindexed distributions will not be tested.
+Valid values are 0 or 1. Defaults to 0.
+
+=item *
+
 C<<< set_term_title >>> -- toggle for whether the terminal titlebar will be
 updated with the distribution being smoke tested and the starting time
 of the test. Helps determine if a test is hung and which distribution
@@ -646,6 +668,11 @@ distribution if --list is provided). Valid values are 0 or 1. Defaults to 0
 
 =item *
 
+C<<< random >>> -- toggle whether to randomize distribution test order. When set to 1,
+the list of releases is shuffled. Valid values are 0 or 1. Defaults to 0
+
+=item *
+
 C<<< force_trust >>> -- toggle whether to override CPAN's
 C<<< trust_test_report_history >>> option. When set to 1, C<<< trust_test_report_history >>>
 is set to 1.  When set to 0, C<<< trust_test_report_history >>> is left alone and
@@ -991,6 +1018,8 @@ David Golden <dagolden@cpan.org>
 
 =head1 CONTRIBUTORS
 
+=for stopwords Alexandr Ciornii Christian Walde gregor herrmann
+
 =over 4
 
 =item *
@@ -1001,11 +1030,15 @@ Alexandr Ciornii <alexchorny@gmail.com>
 
 Christian Walde <walde.christian@googlemail.com>
 
+=item *
+
+gregor herrmann <gregoa@cpan.org>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by David Golden.
+This software is Copyright (c) 2015 by David Golden.
 
 This is free software, licensed under:
 
